@@ -53,10 +53,7 @@ pub use single_qubit_gate_operations::*;
 mod two_qubit_gate_operations;
 pub use two_qubit_gate_operations::*;
 
-/// Auto generated enums of Operations
-#[doc(hidden)]
-mod _auto_generated_operations;
-pub use _auto_generated_operations::*;
+include!(concat!(env!("OUT_DIR"), "/_auto_generated_operations.rs"));
 
 /// Represents qubits involved in a roqoqo Operation.
 #[derive(Debug, PartialEq, Clone, Eq)]
@@ -153,7 +150,7 @@ dyn_clone::clone_trait_object!(Operate);
 /// // 3) The involved qubits are All: all of the qubits in the Circuit are affected by the Operation
 /// let mut qubit_mapping: HashMap<usize, usize> = HashMap::new();
 /// qubit_mapping.insert(0, 1);
-/// let pragma = PragmaRepeatedMeasurement::new("ro".to_string(), Some(qubit_mapping.clone()), 2);
+/// let pragma = PragmaRepeatedMeasurement::new("ro".to_string(), 2, Some(qubit_mapping.clone()));
 /// assert_eq!(pragma.involved_qubits(), InvolvedQubits::All);
 /// ```
 pub trait InvolveQubits {
@@ -306,11 +303,7 @@ pub trait OperatePragma: Operate + InvolveQubits + Substitute + Clone + PartialE
 ///     [0.0, 0.0, 0.0, 1.0 - superop_prob],
 /// ];
 /// assert_eq!(superop, pragma.superoperator().unwrap());
-/// // 2) The probability of the noise Pragma
-/// let proba_pre_exp: f64 = -2.0 * 0.005 * 0.02;
-/// let proba = CalculatorFloat::from(0.5 * (1.0 - proba_pre_exp.exp()));
-/// assert_eq!(proba, pragma.probability());
-/// // 3) The power function applied to the noise Pragma
+/// // 2) The power function applied to the noise Pragma
 /// let pragma_test = PragmaDamping::new(
 ///     0,
 ///     CalculatorFloat::from(0.005 * 1.5),
@@ -324,12 +317,33 @@ pub trait OperatePragmaNoise:
 {
     /// Returns superoperator matrix of the Operation.
     fn superoperator(&self) -> Result<Array2<f64>, RoqoqoError>;
-    /// Returns the probability of the gate, based on its gate_time and rate.
-    fn probability(&self) -> CalculatorFloat;
     /// Returns the gate to the power of `power`.
     fn powercf(&self, power: CalculatorFloat) -> Self;
 }
 
+/// Trait for PRAGMA Operations that are not necessary available on all universal quantum hardware, that indicate noise.
+///
+/// # Example
+/// ```
+/// use ndarray::{array, Array2};
+/// use roqoqo::operations::{OperatePragmaNoiseProba, PragmaDamping};
+/// use qoqo_calculator::CalculatorFloat;
+///
+/// let pragma = PragmaDamping::new(0, CalculatorFloat::from(0.005), CalculatorFloat::from(0.02));
+///
+/// // The probability of the noise Pragma
+/// let proba_pre_exp: f64 = -2.0 * 0.005 * 0.02;
+/// let proba = CalculatorFloat::from(0.5 * (1.0 - proba_pre_exp.exp()));
+/// assert_eq!(proba, pragma.probability());
+/// ```
+///
+pub trait OperatePragmaNoiseProba:
+    Operate + InvolveQubits + Substitute + Clone + PartialEq + OperatePragma + OperatePragmaNoise
+{
+    /// Returns the probability of the gate, based on its gate_time and rate.
+    fn probability(&self) -> CalculatorFloat;
+}
+
 /// Trait for Operations acting with a unitary gate on a set of qubits.
 ///
 /// # Example
